"""
Core functions

Author: Matt Hall, agilescientific.com
Licence: Apache 2.0
"""
pass